import { List } from 'echarts';
import { BasicPageParams, BasicFetchResult } from '/@/api/model/baseModel';
import { Dayjs } from 'dayjs';

//任务管理=》任务列表
export type Tsk_JobParams = {
  JobName?: string;
  CREATE_TIME?: string;
};
export type Tsk_JobPageParams = BasicPageParams & Tsk_JobParams;
export interface Tsk_JobListItem {
  // 主键 GUID
  ID: string;
  //任务名称
  JobName: string;
  // 创建时间
  CREATE_TIME: string;
  // 创建者
  CREATE_USER: string;
  // 修改时间
  UPDATE_TIME: string;
  // 修改者
  UPDATE_USER: string;
  // 删除标记(True:1/False:0)
  GHOST_ROW: string;
  // 组织机构授权标识字段
  AUTH_ORG: string;
  // 生产单元授权标识字段
  AUTH_PROD: string;
  // 仓库单元授权标识字段
  AUTH_WH: string;
  // 作业组名称
  GroupName: string;
  // 作业处理程序类型，存储的是类型的 FuLIName
  JobType: string;
  // 作业处理程序类型所在程序集，存储的是程序集 Name
  AssemblyName: string;
  // 描述信息
  Description: string;
  // 作业执行方式，如果设置为 false，那么使用串行执行，否则并行执行
  Concurrent: number;
  // 是否扫描 IJob 实现类 [Trigger] 特性触发器
  IncludeAnnotations: number;
  // 作业信息额外数据，由 Dictionary<string,object> 序列化成字符串存储
  Properties: string;
  // 作业更新时间
  UpdatedTime: string;
  // 备注
  Remark: string;
  //参数
  Triggers: List<Tsk_TrigListItem>;
  //日志
  Logs: List<Tsk_LogListItem>;
  //时间
  Period: number;
  uPeriod: number;
  //状态
  Status: Number;
}

//任务触发器
export type Tsk_TrigParams = {
  Description?: string;
  CREATE_TIME?: string;
};
export type Tsk_TrigPageParams = BasicPageParams & Tsk_TrigParams;
export interface Tsk_TrigListItem {
  // 作业 Id
  JobId: string;
  // 创建时间
  CREATE_TIME: string;
  // 创建者
  CREATE_USER: string;
  // 修改时间
  UPDATE_TIME: string;
  // 修改者
  UPDATE_USER: string;
  // 作业触发器类型，存储的是类型的 FullName
  TriggerType: string;
  //  作业触发器类型所在程序集，存储的是类型的 Name
  AssemblyName: string;
  //  作业触发器参数，运行时将反序列化为object[]类型并作为构造函数参数
  Args: string;
  //描述信息
  Description: string;
  // 运行状态
  Status: string;
  //起始时间
  StartTime: string;
  // 结束时间
  EndTime: string;
  //最后运行时间
  LastRunTime: string;
  //下一次运行时间
  NextRunTime: string;
  // 触发次数
  NumberOfRuns: number;
  // 最大触发次数，0: 不限制，n: N 次
  MaxNumberOfRuns: number;
  // 出错次数
  NumberOfErrors: number;
  // 最大出错次数，0:不限制，n: N 次
  MaxNumberOfErrors: number;
  //重试次数
  NumRetries: number;
  // 重试间隔时间，毫秒单位
  RetryTimeout: string;
  // 是否立即启动
  StartNow: string;
  // 是否启动时执行一次
  RunOnStart: string;
  // 是否在启动时重置最大触发次数等于一次的作业
  ResetOnlyOnce: string;
  // 本次执行返回结果
  Result: string;
  // 本次执行耗时，单位 ms
  ElapsedTime: number;
  // 作业触发器更新时间
  UpdatedTime: string;
  // 备注
  Remark: string;
}

//任务日志列表
export type Tsk_LogParams = {
  JobId?: string;
  Description?: string;
  CREATE_TIME?: string;
  Status?: any;
};
export type Tsk_LogPageParams = BasicPageParams & Tsk_LogParams;
export interface Tsk_LogListItem {
  // 主键 GUID
  ID: string;
  // 创建时间
  CREATE_TIME: string;
  // 创建者
  CREATE_USER: string;
  // 修改时间
  UPDATE_TIME: string;
  // 修改者
  UPDATE_USER: string;
  // 作业触发器类型，存储的是类型的 FullName
  TriggerType: string;
  //  作业触发器类型所在程序集，存储的是类型的 Name
  AssemblyName: string;
  //  作业触发器参数，运行时将反序列化为object[]类型并作为构造函数参数
  Args: string;
  //操作类型
  Operation: string;
  // 操作人
  Operator: string;
  // 运行状态
  Status: string;
  //起始时间
  StartTime: string;
  // 删除标记
  GHOST_ROW: string;
  // 组织结构授权标识字段
  AUTH_ORG: string;
  // 生产单元授权标识字段
  AUTH_PROD: string;
  // 仓库单元授权标识字段
  AUTH_WH: string;
  // 作业ID
  JobID: string;
  // 结束时间
  EndTime: string;
  // 本次执行耗时
  ElapsedTime: string;
  // 备注
  Remark: string;
}

export type Tsk_JobPageListGetResultModel = BasicFetchResult<Tsk_JobListItem>;

export type Tsk_LogPageListGetResultModel = BasicFetchResult<Tsk_LogListItem>;

export type Tsk_TrigPageListGetResultModel = BasicFetchResult<Tsk_TrigListItem>;

export interface TskParameter extends TrigArgs {
  JobName: string;
  JobType: string;
  AssemblyName: string;
  Remark: string;
  LastRunTime: Dayjs;
}

export interface TrigArgs {
  NonReentrant: string;
  ToRunOnceAtDt: Dayjs;
  runType: number;
  type: number;
  NowAddMinutes: number; //上面时间加多少分钟，表示延迟多少分钟运行
  ToRunEvery: number; //每隔多少运行一回
  ToRunOnceIn: number; //在多少后运行一次
  Milliseconds: number;
  Seconds: number;
  Minutes: number;
  Hours: number;
  Days: number;
  Weekday: number;
  Interval: number;
  ByInterval: string;
}

export interface FluentJobParam {
  AssemblyName: string;
  DataType: string;
  JobName: string;
  Args: TrigArgs;
  Remark: string;
}
